<?php

// fix PHP Fatal error:  Call to undefined function wp_verify_nonce()
require_once( ABSPATH .'wp-includes/pluggable.php' );
// require template.php to use add_settings_error
require_once( ABSPATH .'wp-admin/includes/template.php' );
// to use theme functions
require_once( ABSPATH .'wp-includes/theme.php' );

add_action('admin_menu', 'rebelmouse_create_setting_menu');


rebelmouse_warnings();

/**
 * show error when:
 * we don't have permissions in theme directory and not have the template for fullwidth 
 * and to create home page.
 * 
 * show warning:
 * when don't have writable permission to create home page.
 */
function rebelmouse_warnings(){

    $rembelmouse_template = get_template_directory().'/'.REBELMOUSE_FULL_WIDTH_TEMPLATE;

    if ( ! file_exists( $rembelmouse_template ) ) {

        if ( !is_writable( get_template_directory() ) )  {
            function rebelmouse_alert(){
                global $rebelmouse_admin_page;
                if ( get_current_screen()->id != $rebelmouse_admin_page)
                    return;
                ?>
                <div class='error'>
					<p><strong>RebelMouse Error</strong>: Theme directory is not writable.</p>
					<p><strong><?php echo get_template_directory();?></strong></p>
					<p>Please adjust its file permissions/ownership.</p>
				</div>
                <?php
            }
            add_action( 'admin_notices', 'rebelmouse_alert' );
        } else {
            rebelmouse_add_templates_to_theme();
        }
    }
}



/**
 * Setting link after install the plugin 
 * @return string
 */
function rebelmouse_plugin_action_links( $links, $file ) {
    if ( $file == plugin_basename( dirname(__FILE__).'/rebelmouse-widget.php' ) ) {
        $links[] = '<a href="admin.php?page=rebelmouse-key-setting">'.__('Settings').'</a>';
    }

    return $links;
}
add_filter( 'plugin_action_links', 'rebelmouse_plugin_action_links', 10, 2 );


/**
 * Create the setting link and register settings
 */
function rebelmouse_create_setting_menu() {
    global $rebelmouse_admin_page;
    
    $rebelmouse_admin_page = add_options_page('RebelMouse settings', 'RebelMouse Settings', 'manage_options', 'rebelmouse-key-setting', 'rebelmouse_settings_page');
    add_action( 'admin_init', 'rebelmouse_register_mysettings' );
}


function rebelmouse_register_mysettings() {
    register_setting( 'rebelmouse-settings-group', 'rebelmouse_sitename' );
    register_setting( 'rebelmouse-settings-group', 'rebelmouse_columns' );
}


/**
 * utility to create tabs
 * @param String $current, the current tab name.
 */
function rebelmouse_tabs_setting( $current = 'homepage' ) {
        $tabs = array( 'homepage' => 'Home Settings', 'page' => 'Page Settings' ); ?>
        <h2 class="nav-tab-wrapper">
        <?php 
        foreach( $tabs as $tab => $name ){
            $class = ( $tab == $current ) ? ' nav-tab-active' : '';
            echo "<a class='nav-tab$class' href='?page=rebelmouse-key-setting&tab=$tab'>$name</a>";
        }
        echo '</h2>';
}


/**
 * The admin page for rebelmouse settings.
 */
function rebelmouse_settings_page() { 
    global $rebelmouse_admin_page;

    if ( get_current_screen()->id != $rebelmouse_admin_page)
        return;
    ?>
<div class="wrap">
    
    <div class="icon32" style="background-image:url(<?php echo plugin_dir_url( __FILE__ ) . 'img/TheMouse-32-32.png'?>)" ><br></div>
    <h2>RebelMouse options</h2>
    Add Rebelmouse as your home page or just add a new page just setting you sitename in rebelmouse. 

<form method="post" action="options.php">
    <?php 
    
    if ( isset ( $_GET['tab'] ) ) $tab = $_GET['tab'];
    else $tab = 'homepage';
    
    rebelmouse_tabs_setting( $tab );
    
    settings_fields( 'rebelmouse-settings-group' );
    wp_nonce_field( plugin_basename( __FILE__ ), 'rebelmouse_noncename' );
    
    switch ( $tab ){
        case 'homepage' : 
            $rebelmouse_sitename = get_option('rebelmouse_sitename', 'rebelmouse');
            $rebelmouse_columns = get_option('rebelmouse_columns', '4');
            ?>
    
            <h3>Set RebelMouse as homepage</h3>
            <p>Just put your sitename of rebelmouse and leave as homepage</p>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Site name: </th>
                    <td>
                        <input type="text" name="rebelmouse_sitename" style="width:600px;" value="<?php echo $rebelmouse_sitename?>" placeholder="rebelmouse"><br/>
                        <em>default: rebelmouse</em>
                    </td>
                </tr>
<?php /*
                <tr valign="top">
                    <th scope="row">Columns: </th>
                    <td>
                        <?php 
                        if ($rebelmouse_columns == '3')
                            $three_status = 'checked="checked"';
                        else 
                            $four_status = 'checked="checked"';
                        ?>
                        <input type="radio" id="rebelmouse_columns4" name="rebelmouse_columns" value="4" <?php echo $four_status;?>><label for="rebelmouse_columns4">4</label>
                        <input type="radio" id="rebelmouse_columns3" name="rebelmouse_columns" value="3" <?php echo $three_status;?>><label for="rebelmouse_columns3">3</label><br/>
                    </td>
                </tr> 
*/ ?>
                </table>
        
            <p class="submit">
                <?php 
                    $rebelmouse_on_front = get_option( 'rebelmouse_on_front', false );
                    if ($rebelmouse_on_front) {
                        ?>
                        <input type="submit" class="button-secundary" name="submit_button" value="<?php _e('Remove current home') ?>" />
                        <?php 
                    }
                ?>
                <input type="submit" class="button-primary" name="submit_button" value="<?php _e('Set as Home') ?>" />
            </p>

        <?php
		break; 
		
		case 'page' :  
		    ?>
            <h3>Page settings</h3>
            <p>Add quickly new page with a rebelmouse template</p>
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">Sitename: </th>
                    <td>
                        <input type="text" name="rebelmouse_page_sitename" style="width:600px;" value="" placeholder="rebelmouse"><br/>
                        <em>default: rebelmouse</em>
                    </td>
                </tr>
                <tr valign="top">
                    <th scope="row">Page title: </th>
                    <td>
                        <input type="text" name="rebelmouse_page_title" style="width:600px;" value="" placeholder="Social stream">
                    </td>
                </tr>
<?php /*
                <tr valign="top">
                    <th scope="row">Columns: </th>
                    <td>
                        <input type="radio" id="rebelmouse_page_columns4" name="rebelmouse_page_columns" value="4" checked="checked"><label for="rebelmouse_page_columns4">4</label>
                        <input type="radio" id="rebelmouse_page_columns3" name="rebelmouse_page_columns" value="3" ><label for="rebelmouse_page_columns3">3</label>
                    </td>
                </tr>
*/ ?>
            </table>
        
            <p class="submit">
                <input type="submit" class="button-primary" name="submit_button" value="<?php _e('Add page') ?>" />
            </p>
        <?php 
        break;
        }
        ?>

</form>
</div>
<?php 

}


/**
 * 
 * @param string $site_name
 * @param string $page_title
 * @param int $columns
 * @return int|boolean new page post_id, or false.
 */
function rebelmouse_add_page( $site_name, $page_title, $columns) {
    
    //page only support 3 or 4 columns
    /*
    if ( ! in_array($columns, array(3,4)) )
        $columns = 4;
    */
    
    //$new_page_content = '[rebelmouse site_name="' . $site_name . '" skip="also-on-rm,following"]';
    $new_page_content = '[rebelmouse site_name="' . $site_name . '"]';
    $new_page_template = REBELMOUSE_FULL_WIDTH_TEMPLATE;
    
    $page_check = get_page_by_title($page_title);
    
    $new_page = array(
            'post_type' => 'page',
            'post_title' => $page_title,
            'post_content' => $new_page_content,
            'post_status' => 'publish',
            'post_author' => 1,
    );
    
    $GLOBALS['wp_rewrite'] = new WP_Rewrite();
    $new_page_id = wp_insert_post($new_page);
    if ( is_wp_error($revision_id) )
        add_settings_error( $rebelmouse_admin_page, 'rebelmouse_page_error', 'something happen try again.', 'error');
    elseif(!empty($new_page_template)){
        update_post_meta($new_page_id, '_wp_page_template', $new_page_template);
        return $new_page_id;
    }
    return false;
}


if ( $_POST['action'] == 'update' && wp_verify_nonce( $_POST['rebelmouse_noncename'], plugin_basename( __FILE__ ) ) ){

    if ( $_POST['submit_button'] === translate( 'Add page' ) ){

        $rebelmouse_page_sitename = esc_html( $_POST['rebelmouse_page_sitename'] );
        $rebelmouse_page_sitename = ( !empty($rebelmouse_page_sitename) )? $rebelmouse_page_sitename: 'rebelmouse';
        $rebelmouse_page_title = esc_html( $_POST['rebelmouse_page_title'] );
        $rebelmouse_page_title = ( !empty($rebelmouse_page_title) )? $rebelmouse_page_title: $rebelmouse_page_sitename;
        $rebelmouse_page_columns = intval( esc_html( $_POST['rebelmouse_page_columns'] ) );

        $page_id = rebelmouse_add_page($rebelmouse_page_sitename, $rebelmouse_page_title, $rebelmouse_page_columns);
        
        if ( !empty($page_id) ){
            add_settings_error( $rebelmouse_admin_page, 'rebelmouse_page_created', sprintf('Page created, you can edit <a href="%s">as other pages</a>, and see in action <a href="%s">here</a>.',  get_admin_url(null, 'edit.php?post_type=page'), get_permalink($page_id)), 'updated');
        }

    } elseif ( $_POST['submit_button'] === translate( 'Set as Home' ) ){

        update_option('rebelmouse_sitename', esc_html( $_POST['rebelmouse_sitename'] ) );
        $rebelmouse_sitename = esc_html( $_POST['rebelmouse_sitename'] );
        $rebelmouse_sitename = ( !empty($rebelmouse_sitename) )? $rebelmouse_sitename: 'rebelmouse';

        //page only support 3 or 4 columns
        $rebelmouse_columns = intval( esc_html( $_POST['rebelmouse_columns'] ) );
        update_option('rebelmouse_columns', $columns );

        $page_id = rebelmouse_add_page($rebelmouse_sitename, $rebelmouse_sitename, $rebelmouse_columns);

        if ( !empty($page_id) ){
            
            update_option( 'show_on_front', 'page' );
            update_option( 'page_on_front', $page_id );
            update_option( 'rebelmouse_on_front', $rebelmouse_sitename );
            update_option( 'rebelmouse_page_on_front', $page_id );
            
            add_settings_error( $rebelmouse_admin_page, 'rebelmouse_home_created', sprintf('Home created, check it out <a href="%s">here</a>.', get_bloginfo('url')), 'updated');
        }
        
        
    } elseif ( $_POST['submit_button'] === translate( 'Remove current home' ) ){

        $homepage_id = get_option( 'page_on_front');
        
        update_option( 'show_on_front', 'posts' );
        update_option( 'page_on_front', 0 );
        update_option( 'rebelmouse_on_front', '' );
        update_option( 'rebelmouse_page_on_front', 0 );
        
        wp_delete_post( $homepage_id, true );
        
    }
}

?>
