<?php
/*
 * Plugin Name: RebelMouse Widget
 * Plugin URI: http://www.rebelmouse.com
 * Description: Add your RebelMouse to your blog. Add and edit in the widgets tab of WordPress or using shortcode.
 * Version: 1.3
 * Author: Francisco Lavin
 * Author URI: http://www.rebelmouse.com/flavin
 *License: GPLv2 or later
 */

/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

define( 'REBELMOUSE_FULL_WIDTH_TEMPLATE', 'page-rebelmouse-4-columns.php' );

require_once( dirname(__FILE__) . '/rebelmouse-utils.php');
require_once dirname( __FILE__ ) . '/rebelmouse-admin.php';

/**
 * Templates functions
 **/
function rebelmouse_template_custom_activation() {
    rebelmouse_add_templates_to_theme();
}
register_activation_hook( __FILE__, 'rebelmouse_template_custom_activation' );


function rebelmouse_template_custom_deactivation() {
    rebelmouse_remove_template_from_theme();
}
register_deactivation_hook( __FILE__, 'rebelmouse_template_custom_deactivation' );


/**
 * copy the rebelmouse plugin template for page, to the current theme.
 */
function rebelmouse_add_templates_to_theme(){

    $src_template = dirname( __FILE__ ).'/templates/'.REBELMOUSE_FULL_WIDTH_TEMPLATE;
    $dst_template = get_template_directory().'/'.REBELMOUSE_FULL_WIDTH_TEMPLATE;

    if( ! file_exists( $dst_template ) ) {
        $data = file_get_contents($src_template);
        if ( ! rebelmouse_create_page_template( $data, get_template_directory(), REBELMOUSE_FULL_WIDTH_TEMPLATE) ) {
            //wp_die('plugin need write permissions on the template');
        }
    }
}


function rebelmouse_create_page_template($data, $dst_dir,  $dst_file){
    $result = false;
    
    $destination = get_template_directory().'/'.$dst_file;
    
    if ( file_exists($destination) ) {
        //backup home
        $bkp_file = tempnam($dst_dir, $dst_file);
        rename($destination, $bkp_file);
    }

    if ( !file_exists($destination) ){
        $handle = fopen($destination, "w");
        $result = fwrite($handle, $data);
        fclose($handle);
    } 
    
    return $result;
}


function rebelmouse_remove_template_from_theme(){
    
     rebelmouse_remove_templates_files( REBELMOUSE_FULL_WIDTH_TEMPLATE );
     
}

function rebelmouse_remove_templates_files( $file ) {
    
    //only remove home.php and REBELMOUSE_FULL_WIDTH_TEMPLATE
    if ( in_array( $file, array(REBELMOUSE_FULL_WIDTH_TEMPLATE)) ) {
    
        $dst_template = get_template_directory().'/'.$file;
        //$handle = fopen($dst_template);
        //fclose($handle);
        return unlink($dst_template);
    }
    return false;
}


/**
 * Register the Widget
 */
add_action( 'widgets_init', create_function( '', 'register_widget("rebelmouse_widget");' ) );

/**
 * Create the widget class and extend from the WP_Widget
 */
 class Rebelmouse_Widget extends WP_Widget {

	/**
	 * Set the widget defaults
	 */
	private $widget_title = "RebelMouse Widget";
	private $show_stream = "true";
	private $site_name = "rebelmouse";
	private $cols = 1;
	private $scroll = "auto";

	private $width = "";
	private $height = "1500";

	private $skip = array();
	private $show_about = "true";
	private	$show_following = "true";
	private	$show_also_in_rm = "true";
	private	$show_share = "true";

	private	$show_button = "true";
	private	$theme_button = "clear";

	/**
	 * Register widget with WordPress.
	 */
	public function __construct() {

		parent::__construct(
			'Rebelmouse_Widget',// Base ID
			'RebelMouse ',// Name
			array(
				'classname'		=>	'Rebelmouse_Widget',
				'description'	=>	__('A widget to add your rebelmouse stream.', 'framework')
			)
		);

	} // end constructor

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args );

		/* Our variables from the widget settings. */
		$this->widget_title = apply_filters('widget_title', $instance['title'] );

		$this->show_stream = ($instance['show_stream'] == "1" ?  True : False);
		$this->site_name = $instance['site_name'];
		$this->cols = $instance['cols'];
		$this->scroll = $instance['scroll'];
		$this->height = $instance['height'];

		$this->show_button = ($instance['show_button'] == "1" ?  True : False);
		$this->theme_button = $instance['theme_button'];

        $skip = ($instance['show_about'] == "1" ?  "" : "about-site,");
        $skip .= ($instance['show_following'] == "1" ? "" : "following," );
        $skip .= ($instance['show_also_in_rm'] == "1" ? "" : "also-on-rm," );
        $skip .= ($instance['show_share'] == "1" ? "" : "share-frontpage" );

		/* Before widget (defined by themes). */
		echo $before_widget;

		/* Display the widget title if one was input (before and after defined by themes). */
		if ( $this->widget_title )
			echo $before_title . $this->widget_title . $after_title;

		/* RebelMouse Render*/
        $this->render( array('show_stream' => $this->show_stream, 'site_name' => $this->site_name
                            , 'cols' => $this->cols, 'skip' => $skip, 'width' => $this->width
                            , 'scroll' => $this->scroll, 'height' => $this->height
                            , 'show_button' => $this->show_button, 'theme_button' => $this->theme_button ) );

		/* After widget (defined by themes). */
		echo $after_widget;
	}

    public function render( $args ) {
        echo $this->get_rm_render( $args );
    }

    public function get_rm_render( $args ) {
        $r = wp_parse_args( $args
                            , array('show_stream' => True
                                    ,'site_name' => 'rebelmouse'
                                    ,'cols' => '1'
                                    ,'skip' => ''
                                    ,'width'=> ''
                                    ,'height' => '0'
                                    ,'show_button' => True
                                    ,'theme_button' => 'clear'
                                    ,'scroll' => 'auto'
                                    ) );

        $r['cols'] = intval( $r['cols'] );
        if ( empty( $r['cols'] ) )
            $r['cols'] = 1;
        elseif ( $r['cols'] > 5 )
            $r['cols'] = 5;
                
        if ( empty( $r['height'] ) ) {
            $is_flexible = true;
            //$r['height'] = '1500px';
            $r['height'] = '1500';
            $r['flexible'] = '1';
        } else {
            $is_flexible = false;
            //$r['height'] .= 'px';
            $r['flexible'] = '0';
        }

        if ( empty( $r['width'] ) )
            $r['width'] = '100%';
            //$r['width'] = ($r['cols']*257).'px';
        elseif ( ! rm_endsWith( $r['width'], '%') && ! rm_endsWith( $r['width'], 'px') )
            $r['width'] .= 'px';

        $params = 'embedded=1';

        //$params .= '&cols=' . $r['cols'];

        if ( !empty( $r['skip'] ) )
            $params .= '&skip=' . $r['skip'];

        $scrolling = '';
        if ( $r['scroll'] === 'no' )
            $scrolling = 'scrolling="no"';
        elseif ( $r['scroll'] === 'yes' )
            $scrolling = 'scrolling="yes"';

        $output = '<script type="text/javascript" id="rebelmouse-embed-script" src="https://www.rebelmouse.com/static/js-build/embed/embed.js?site=' . $r['site_name'] . '&height=' . $r['height'] . '&flexible=' . $r['flexible'] . '&skip=' . $r['skip'] . '"></script>';

        return $output;
    }

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		/* Strip tags for title and name to remove HTML (important for text inputs). */
		$instance['title'] = strip_tags( $new_instance['title'] );
		$instance['show_stream'] = (bool)$new_instance['show_stream'];
		$instance['site_name'] = strip_tags( $new_instance['site_name'] );
		$instance['cols'] = strip_tags( $new_instance['cols'] );
		$instance['scroll'] = strip_tags( $new_instance['scroll'] );

		//$instance['width'] = strip_tags( $new_instance['width'] );
		$instance['height'] = strip_tags( $new_instance['height'] );

		$instance['show_about'] = (bool)$new_instance['show_about'];
		$instance['show_following'] = (bool)$new_instance['show_following'];
		$instance['show_also_in_rm'] = (bool)$new_instance['show_also_in_rm'];
		$instance['show_share'] = (bool)$new_instance['show_share'];

		$instance['show_button'] = (bool)$new_instance['show_button'];
		$instance['theme_button'] = $new_instance['theme_button'];

		return $instance;
	}

	/**
	 * Create the form for the Widget admin
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	function form( $instance ) {

		/* Set up some default widget settings. */
		$defaults = array(
		'title' => $this->widget_title,
	    'show_stream' => $this->show_stream,
		'site_name' => $this->site_name,
		'cols' => $this->cols,
		'scroll' => $this->scroll,

		'width' => $this->width,
		'height' => $this->height,
		'show_about' => $this->show_about,
		'show_following' => $this->show_following,
		'show_also_in_rm' => $this->show_also_in_rm,
		'show_share' => $this->show_share,
        'border_color' => $this->border_color,

		'show_button' => $this->show_button,
		'theme_button' => $this->theme_button
		);

		$instance = wp_parse_args( (array) $instance, $defaults ); ?>

        <!-- Widget Title: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e('Title', 'framework') ?>: </label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo $instance['title']; ?>" />
		</p>

		<!-- Page name: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'site_name' ); ?>"><?php _e('Site name', 'framework') ?>: </label>
			<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'site_name' ); ?>" name="<?php echo $this->get_field_name( 'site_name' ); ?>" value="<?php echo $instance['site_name']; ?>" />
            <br><small>default: rebelmouse</small>
		</p>


		<p>
        <strong>Advance settings:</strong>
		</p>
        
		<!-- Show About: Checkbox -->
        <p>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_about' ); ?>" name="<?php echo $this->get_field_name( 'show_about' ); ?>" value="1" <?php echo ($instance['show_about'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_about' ); ?>" style="vertical-align: baseline;" ><?php _e('Show About', 'framework') ?></label>
		<br>

        <?php /*
		<!-- Show Following: Checkbox -->
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_following' ); ?>" name="<?php echo $this->get_field_name( 'show_following' ); ?>" value="1" <?php echo ($instance['show_following'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_following' ); ?>"><?php _e('Following', 'framework') ?></label>
		<br>

		<!-- Show Also in RebelMouse: Checkbox -->
			<input type="checkbox" id="<?php echo $this->get_field_id( 'show_also_in_rm' ); ?>" name="<?php echo $this->get_field_name( 'show_also_in_rm' ); ?>" value="1" <?php echo ($instance['show_also_in_rm'] == "true" ? "checked='checked'" : ""); ?> />
			<label for="<?php echo $this->get_field_id( 'show_also_in_rm' ); ?>"><?php _e('Also In RebelMouse', 'framework') ?></label>
		<br>
         */?>
		</p>

		<!-- Height: Text Input -->
		<p>
			<label for="<?php echo $this->get_field_id( 'height' ); ?>"><?php _e('Height', 'framework') ?>: </label>
			<input type="text" id="<?php echo $this->get_field_id( 'height' ); ?>" name="<?php echo $this->get_field_name( 'height' ); ?>" value="<?php echo $instance['height']; ?>" size="5" />px
			<br><small>leave empty to make rebelmouse widget autoadjustable</small>
		</p>

	<?php
	}
 }


/**
 * Display the embed of rebelmouse stream
 *
 * The list of arguments is below:
 *     'site_name' (string) - You rebelmouse site name
 *     'skip' (String) - Element to hide in the stream: about-site
 *     'height' (int) - height of the iframe
 *
 * @param string|array $args Optional. Override the defaults.
 */ 
function rebelmouse_embed( $args ) {
    $rm_widget = new Rebelmouse_Widget();
    $rm_widget->render( $args );
}

/**
 * Shortcode to diplay rebelmouse in your site.
 * 
 * The list of arguments is below:
 *     'site_name' (string) - You rebelmouse site name
 *                    Default: rebelmouse
 *     'skip' (String) - Element to hide in the stream: about-site
 *     'height' (int) - height of the iframe
 *                    Default: initial auto adjustable to 20 posts.
 * 
 * Usage: 
 * [rebelmouse sitename="rebelmouse"]
 * [rebelmouse sitename="rebelmouse" h="1500"]
 */
function rebelmouse_shortcode( $atts ) {
    extract( shortcode_atts( array(
        'site_name' => '',
        'sitename' => '',
        'cols' => 2,
        'skip' => '',
        'height' => '',
        'h' => '',
        'show_button' => 'true',
        'theme_button' => 'clear',
        'show_stream' => 'true',
        'scroll' => 'auto',
        'width'=> '',
        'w'=> ''
    ), $atts ) );

    $rm_widget = new Rebelmouse_Widget();

    $width = (!empty($w))? $w: $widht;
    $height = (!empty($h))? $h: $height;
    $site_name= (!empty($sitename))? $sitename: $site_name;
    
    return $rm_widget->get_rm_render( array(
        'site_name' => $site_name,
        'cols' => $cols,
        'skip' => $skip,
        'height' => $height,
        'show_button' => $show_button,
        'theme_button' => $theme_button,
        'show_stream' => $show_stream,
        'scroll' => $scroll,
        'width' => $width
    ) );
}
add_shortcode( 'rebelmouse', 'rebelmouse_shortcode' );

?>
